@@ -31,9 +31,11 @@ etc. The local part can be used as a method, these are autoloaded.
 
 This is the constructor. You may pass a string with a URI or a URI object.
 
-=item C<< uri >>
+=item C<< uri ( [ $local_part ] ) >>
 
-Returns a L<URI> object with the namespace URI.
+Returns a L<URI> object with the namespace URI. Optionally, the method
+can take a local part as argument, in which case, it will return the
+namespace URI with the local part appended.
 
 =back
 
@@ -56,25 +58,30 @@ See L<URI::NamespaceMap> for further details about authors, license, etc.
 around BUILDARGS => sub {
     my ($next, $self, @parameters) = @_;
     return $self->$next(@_) if ((@parameters > 1) || (ref($parameters[0]) eq 'HASH'));
-    return { uri => $parameters[0] };
+    return { _uri => $parameters[0] };
 };
 
 class_type 'URI';
 coerce 'URI' => from 'Str' => via { URI->new($_) };
 
-has uri => ( 
-    is => 'ro', 
-    isa => 'URI', 
+has _uri => ( 
+    isa => 'URI',
 	 coerce => 1,
     required => 1,
+	 reader => '_uri',
 	 handles => ['as_string', 'as_iri', 'canonical', 'eq', 'abs', 'rel']
 );
 
+sub uri {
+    my ($self, $name) = @_;
+    return URI->new($self->_uri . "$name");
+}
+
 our $AUTOLOAD;
 sub AUTOLOAD {
   my $self = shift;
   my ($name) = $AUTOLOAD =~ /::(\w+)$/;
-  return URI->new($self->uri . "$name");
+  return $self->uri($name);
 }
 
 
